@@ -1,10 +1,6 @@
 c           need Zcoord.h  Zobs.h  Zpos.h Zmagfield.h
 	integer NoOfSites           ! No of particle observation sites
         integer NoOfASSites
-	real*8  XaxisFromSouth      ! in degree.  counter clockwise angle of
-c                                      x-axis of 'detector' from the south
-c                                      x-axis is assumed to be directed to
-c                                      magnetic-east 
 c          
 	real*8 CosLatitude          ! oos of Latitude of deepest obs. site
         real*8 SinLatitude          ! sin
@@ -20,6 +16,7 @@ c
                                     ! these are computed in cprimxyz in
                                     ! ciniTracking in ceventLoop
 
+        record /coord/ PolarInjPos  ! polar angle of the injection point in xyz.
 
 	record /magfield/ MagfieldNED     ! mag in 'ned' at deepest obs. site
         record /magfield/ MagfieldHVA     ! mag in 'hva' at //. both in T.
@@ -47,6 +44,6 @@ c            to store Ne, age of a component shower for an electron
      *     MagfieldNED, MagfieldHVA, MagfieldXYZ, 
      *     CompASNe, CompASAge,
      *     DetZaxis, DetXaxis, Xprimary, Yprimary, Zprimary,
-     *     XaxisFromSouth, 
+     *     PolarInjPos, 
      *     CosLatitude, SinLatitude, CosLongitude, SinLongitude,
      *     NoOfSites,    NoOfASSites
