@@ -56,8 +56,9 @@ c	(->	--------------------------------------------
                                !    It can by binary or ascii file depending on Trace value.
 	logical ThinSampling  !1  if F, thinsampling is not tried. if T, alla Hillas thinning. Don't use with
                               !    the  skeleton/flesh method 
-        real*8  EthinRatio    !2  if ThinsSamplig != 0, thin sampling is performed if the energy of a particle is
-                              !   < EthinRatio * PrimaryEnergy(/nucleon) (=Ethin)
+        real*8  EthinRatio    !2  if ThinsSamplig != F, thin sampling is performed if the energy of a particle is
+                              !   < EthinRatio * PrimaryEnergy(/nucleon) (=Ethin) ( EtinRatio> 0).
+                              !  If EthinRatio < 0, Ethin will be |EthinRatio| (GeV). 
         logical TimeStructure !1  If T,  time information is computed
 	integer HowGeomag     !2  if 1, no magnetic field until first coll.
                               !      2, mag.f always exists. If Reverse not=0, use this.
@@ -65,8 +66,11 @@ c	(->	--------------------------------------------
                               !     12, same as 2 but mag.f is const.
                               !     21, same as 1 but mag.f is const.
                               !     22, same as 2 but mag.f is const. 
+                              !     31, same as 1 but mag.f is dependent on the position. 
                               !  const value is the one at deepest observation plane. for 11,12  or should be given by
                               !  MagN, MagE, MagD for 21, 22. For normal applications,  11 is good.
+                              !  If no magnetic field is applied, energy loss by dE/dx is considered.(bef.4.92,
+                              !  and aft. 5.14)
         real*8  MagN          !2 See HowGeomag (in Tesla)
 	real*8  MagE          !2 See HowGeomag (in Tesla)
         real*8  MagD          !2 See HowGeomag (in Tesla)
