@@ -36,6 +36,15 @@ c
 c                  
 c
       cross = .false.
+c       if go out of the boundary,   discard it
+      if(MovedTrack.pos.height .ge. BorderHeightH) then
+         MoveStat = BorderH
+         return                 !  ***************
+      endif
+      if(MovedTrack.pos.height .le. BorderHeightL) then
+         MoveStat = BorderL
+      endif
+
       if(ObsPlane .ne. notUsed ) then
          loc = MovedTrack.where 
          if(abs(ObsPlane) .eq. horizontal) then
@@ -259,22 +268,14 @@ c            endif
          endif
       endif
       if(.not. cross .or. ObsPlane .eq. notUsed) then
-c
 c            see if go out of outer boundery.
-         call cscalerProd(MovedTrack.vec.w, DcAtObsXyz, cosfromaxis)
-         if(cosfromaxis .lt. BackAngLimit .or.
-     *        MovedTrack.pos.height .ge. BorderHeightH) then
-c             discard it
-            MoveStat = BorderH
-            return              !  ***************
-         endif
-c  -------------------------------------------------------------
-
-
-         if(MovedTrack.pos.height .le. BorderHeightL) then
-            MoveStat = BorderL
-c         leng = clenbetween2h(TrackBefMove.pos.height+Eradius,
-c     *         BorderL+Eradius, TrackBefMove.vec.coszenith)
+         if(BackAngLimit .gt. -1.0) then
+            call cscalerProd(MovedTrack.vec.w, DcAtObsXyz, cosfromaxis)
+            if(cosfromaxis .lt. BackAngLimit) then
+c                discard it
+               MoveStat = BorderH
+               return           !  ***************
+            endif
          endif
       endif
       end
