@@ -1,9 +1,9 @@
 c          test kpmnx
 c
 c      include  "kgamma.f"
-c      real*8 x, y, sint
+c      real*4 x, y, sint
 c      integer m, n
-c      real*8 kpmnxn
+c      real*4 kpmnxn
 cc      
 c      read(*,*) m, n
 c      
@@ -26,18 +26,18 @@ c       P(1, 0, x) = 2x
 c       P(1, 1, x) = 2(1-x**2)**(1/2)
 c       P(1, m, x) = 0 ( m>=2 ) 
 c
-      real*8 function krmnx(m, n, x)
+      real*4 function krmnx(m, n, x)
       implicit none
       integer m  !  input  >=0
       integer n  !  input. >=0
-      real*8  x  !  input. argument |x| <= 1
+      real*4  x  !  input. argument |x| <= 1
       
 
 c         m-th derivative of  Pn(x)
 c     where Pn(x) = 1/(2^2 n!) (x^2-1)^n
 c
-      real*8  r0m, r1m, rn, rn1, rn2, krnnx
-      real*8 kpnx
+      real*4  r0m, r1m, rn, rn1, rn2, krnnx
+      real*4 kpnx
 
       integer i
 
@@ -49,10 +49,12 @@ c
 c             m=0
          krmnx = kpnx(n, x)
       elseif(m .gt. n) then
-         krmnx = 0.d0
+c         krmnx = 0.d0
+         krmnx = 0.
       elseif(n .ge. 1) then
          if(m .eq. 1) then
-            r1m = 1.d0
+c            r1m = 1.d0
+            r1m = 1.0
             r0m = 0.
          else
 c              m > 1
@@ -83,18 +85,18 @@ c          n=0, m=0
       endif
       end
 c     **********************************************
-      real*8 function krnnx(n,  x)
+      real*4 function krnnx(n,  x)
       implicit none
 c          kpmnx for n=m case. 
       integer n  ! input
-      real*8  x  ! input.
+      real*4  x  ! input.
 c
 c        r(n,m) = r(n-2,m) + (2n-1)*r(n-1, m-1)
 c        since  n=m, r(n-2,m) is always 0.
 c    So r(n) = (2n-1)*r(n-1)
 c        r(0) = 1. 
 c
-      real*8 r
+      real*4 r
       integer i
 
 
@@ -102,7 +104,8 @@ c
          write(0,*) 'error input to krnnx; n=',n
          stop 999
       else
-         r = 1.d0
+c         r = 1.d0
+         r = 1.0
          do i = 1, n
             r = (2*i-1)*r
          enddo
@@ -120,8 +123,9 @@ cc       kdpmnxn:  sqrt( em* (n-m)!/ (n+m)! ) * kdpmnx
 cc        kpmnxn:  sqrt( em* (n-m)!/(n+m)!  ) * kpmnx
 c      implicit none
 c      integer m, n
-c      real*8 x, y, y1, y2, z, kpmnx, kgamma
-c      real*8 kpnx, kdpmnx, kdpmnxn
+c      real*4 x, y, y1, y2, z, kpmnx
+c      real*8 kgamma
+c      real*4 kpnx, kdpmnx, kdpmnxn
 c      integer mv
 c      read(*, *) mv
 c      do  m=mv, mv
@@ -142,21 +146,23 @@ c         enddo
 c      enddo
 c      end
 c*********************************************************************
-      real*8 function kpnx(n, x)
+      real*4 function kpnx(n, x)
       implicit none
-      real*8 x
+      real*4 x
       integer n
 c           Legendre polinomial  (n>=0)
-      real*8 pim, pimm, pi
+      real*4 pim, pimm, pi
       integer nc/0/, i
 c
            if(n .eq. 0) then
-              kpnx=1.d0
+c              kpnx=1.d0
+              kpnx=1.0
            elseif(n .eq. 1) then
               kpnx=x
            elseif(n .ge. 2) then
               pim=x
-              pimm=1.d0
+c              pimm=1.d0
+              pimm=1.0
               do   i=2, n
                   pi=( (2*i-1)*x *pim - (i-1)*pimm )/i
                   pimm=pim
@@ -168,55 +174,56 @@ c
                  write(*,*) ' n=',n,' invalid for kpnx'
                  nc=nc+1
               endif
-              kpnx=1.d50
+c              kpnx=1.d50
+              kpnx=1.e35
            endif
        end
 c **************************************
-       real*8 function kpmnx(m, n, sint, x)
+       real*4 function kpmnx(m, n, sint, x)
        implicit none
-       real*8 x, sint
+       real*4 x, sint
        integer m, n
 c
-       real*8 krmnx
+       real*4 krmnx
        kpmnx = sint**m * krmnx(m, n, x)
        end
 c      ********************************
-       real*8 function kpmnxn(m, n, sint, x)
+       real*4 function kpmnxn(m, n, sint, x)
        implicit none
-       real*8 x, sint
+       real*4 x, sint
        integer m, n
 c               sqrt(em*(n-m)!/(n+m)!)* kpmnx(m, n, x )
-       real*8 kpnorm, kpmnx
+       real*4 kpnorm, kpmnx
        kpmnxn=kpnorm(m, n)* kpmnx(m, n, sint, x)
        end
 c      *********************
-       real*8 function kpmnxisin(m, n, sint, x)
+       real*4 function kpmnxisin(m, n, sint, x)
        implicit none
        integer m, n   ! m >= 1 
-       real*8 x      
-       real*8 sint   !  sqrt(1.-x**2)
+       real*4 x      
+       real*4 sint   !  sqrt(1.-x**2)
 c     
-       real*8 krmnx
+       real*4 krmnx
        
        kpmnxisin = sint**(m-1) * krmnx(m, n, x)
        end
 c       ********************
-       real*8 function kpmnxisinn(m, n, sint, x)
+       real*4 function kpmnxisinn(m, n, sint, x)
        implicit none
        integer m, n  !  m >=1
-       real*8 x
-       real*8 sint  !  sint = sqrt(1-x**2)
-       real*8 kpmnxisin, kpnorm
+       real*4 x
+       real*4 sint  !  sint = sqrt(1-x**2)
+       real*4 kpmnxisin, kpnorm
        kpmnxisinn = kpnorm(m, n)*kpmnxisin(m, n, sint, x)
        end
 c        **********************
-       real*8 function kdpmnxsin(m, n, sint, x)
+       real*4 function kdpmnxsin(m, n, sint, x)
        implicit none
-       real*8 x
-       real*8 sint
+       real*4 x
+       real*4 sint
        integer m, n
 
-       real*8 krmnx
+       real*4 krmnx
        if(m .gt. 0) then
           kdpmnxsin= (-m*x*krmnx(m, n, x) + sint*sint*krmnx(m+1, n, x))
      *              *sint**(m-1)
@@ -224,20 +231,21 @@ c        **********************
           kdpmnxsin=  sint*krmnx(1, n, x)
        endif
        end
-       real*8 function kdpmnxsinn(m, n, sint, x)
+       real*4 function kdpmnxsinn(m, n, sint, x)
        implicit none
-       real*8 x
-       real*8 sint
+       real*4 x
+       real*4 sint
        integer m, n
 c          
-       real*8 kpnorm, kdpmnxsin
+       real*4 kpnorm, kdpmnxsin
        kdpmnxsinn = kpnorm(m, n)* kdpmnxsin(m,  n, sint, x)
        end
 c *************
-       real*8 function kpnorm(m, n)
+       real*4 function kpnorm(m, n)
        implicit none
        integer m, n
-       real*8 pnorms, em, kgamma
+       real*4 pnorms, em
+       real*8 kgamma
        save pnorms
 c
        integer ms/-1/, ns/-1/
@@ -246,7 +254,7 @@ c
 
        integer nn, i
        parameter (nn=30)
-       real*8 fact(0:nn), dv, dn
+       real*4 fact(0:nn), dv, dn
        save first, fact, ms, ns
        data first /.true./
 
@@ -259,14 +267,14 @@ c
        endif
        if(m .eq. ms .and. n .eq. ns)then
        elseif(m .gt. n) then
-          pnorms=0.d0
+          pnorms=0.0
        else
           ms = m
           ns = n 
           if(m .eq. 0)then
-             em=1.d0
+             em=1.0
           else
-             em=2.d0
+             em=2.0
           endif
           if(n-m  .le. nn) then
              dn = fact(n-m)
@@ -282,3 +290,6 @@ c
        endif
        kpnorm=pnorms
        end
+
+
+
